@@ -1,21 +1,8 @@
 /*  This file is part of the KDE libraries
-    Copyright (c) 2000 Matthias Hoelzer-Kluepfel <mhk@caldera.de>
+    SPDX-FileCopyrightText: 2000 Matthias Hoelzer-Kluepfel <mhk@caldera.de>
 
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef __kio_man_h__
 #define __kio_man_h__
@@ -54,15 +41,15 @@ public:
     char *readManPage(const char *filename);
 
     static MANProtocol *self();
-   
+
 private:
     void checkManPaths();
     QStringList manDirectories();
     QMap<QString, QString> buildIndexMap(const QString& section);
     bool addWhatIs(QMap<QString, QString>& i, const QString& f, const QString& mark);
     void parseWhatIs( QMap<QString, QString> &i, QTextStream &t, const QString &mark );
-    QStringList findPages(const QString& section, 
-                          const QString &title, 
+    QStringList findPages(const QString& section,
+                          const QString &title,
                           bool full_path = true);
 
     QStringList buildSectionList(const QStringList& dirs) const;
