@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2000 Caldera Systems, Inc.
+    SPDX-FileCopyrightText: 2000 Caldera Systems Inc.
     SPDX-FileCopyrightText: 2018-2020 Harald Sitter <sitter@kde.org>
     SPDX-FileContributor: Matthew Peterson <mpeterson@caldera.com>
 */
@@ -74,7 +74,7 @@ void SMBSlave::get(const QUrl &kurl)
                 buffer.push();
                 buffer.done();
                 if (s->size < 0) {
-                    return KIO::ERR_COULD_NOT_READ;
+                    return KIO::ERR_CANNOT_READ;
                 }
                 break;
             }
