@@ -31,7 +31,8 @@
 class PBSDResolver : public QObject
 {
     Q_OBJECT
-signals:
+
+Q_SIGNALS:
     void resolved(Discovery::Ptr discovery);
 
 public:
@@ -122,9 +123,9 @@ public:
             const auto childValues = response.childValues();
             for (const auto &section : qAsConst(childValues)) {
                 computer = section
-                        .childValues().child("Relationship")
-                        .childValues().child("Host")
-                        .childValues().child("Computer").value().toString();
+                           .childValues().child("Relationship")
+                           .childValues().child("Host")
+                           .childValues().child("Computer").value().toString();
                 if (!computer.isEmpty()) {
                     break;
                 }
@@ -163,7 +164,7 @@ public:
         }
 
         m_discovery.reset(new WSDiscovery(computer, host));
-        emit resolved(m_discovery);
+        Q_EMIT resolved(m_discovery);
     }
 
 private:
@@ -267,7 +268,7 @@ void WSDiscoverer::resolveReceived(const WSDiscoveryTargetService &service)
     PBSDResolver *resolver = new PBSDResolver(addr, service.endpointReference(), this);
     connect(resolver, &PBSDResolver::resolved, this, [this](Discovery::Ptr discovery) {
         ++m_resolvedCount;
-        emit newDiscovery(discovery);
+        Q_EMIT newDiscovery(discovery);
         maybeFinish();
     });
     QTimer::singleShot(0, resolver, &PBSDResolver::run);
@@ -277,7 +278,7 @@ void WSDiscoverer::resolveReceived(const WSDiscoveryTargetService &service)
 void WSDiscoverer::maybeFinish()
 {
     if (isFinished()) {
-        emit finished();
+        Q_EMIT finished();
     }
 }
 
